function x = myrandn( mu_x, Cov_xx, n )

% Random vectors from the multivariate normal distribution.
%
% x = myrandn( mu_x, Cov_xx, n ) generates n random variables 
% vector x according to x ~ N(mu,Cov_xx)
%
%    author:  J. Meidow, Institut for Photogrammetry, Univ. Bonn
%                        FGAN-FOM
% 2007, Jan:  return n vectors

if nargin==2
    n = 1;
end

% Cov_xx = R*Cov_yy*R',  Cov_yy: diag
[R Cov_yy] = eig( Cov_xx );
Cov_yy( Cov_yy<0)=0;

%  y ~ N(0,Cov_yy)
z = randn( size(Cov_yy,1),n );

% x ~N(mu_x, Cov_xx)
x = R*sqrt(Cov_yy)*z +repmat(mu_x,1,n);

return