function plot_gnomonic_projection( K, I, v, eCov, qu, color)

% plot_gnomonic_projection( K, I, v, eCov, qu, color)
%
%     K: camera calibration matrix
%     I: image
%     v: vanishing point coordinates, homogeneous, 9x1
%  eCov: corresponding covariance matrix, 9x9
%    qu: factor for enlargement of uncertainty regions
% color: string of 3 color characters, e.g. 'rgb' 
%
% author: J. Meidow, FGAN-FOM

% plot the sphere and its equator
[x,y,z] = sphere;
surf(0.99*x,0.99*y,0.99*z, 'FaceColor',0.8*[1 1 1]);
i = (size(x,2)+1)/2;
plot3( 0.99*x(i,:),0.99*y(i,:),0.99*z(i,:), 'k-', 'LineWidth', 2);

% image coordinates
x = 1:size(I,1);  % rows,cols
y = 1:size(I,2);
[x,y]  =      meshgrid( x, y);
z       =     ones( size(x) );

K(1,1) = 1*K(1,1);
K(2,2) = 1*K(2,2);

iK = inv(K);

% camera coordinates
tmp = iK*[x(:), y(:), z(:) ]';
x = tmp(1,:);
y = tmp(2,:);
z = tmp(3,:);

% project to sphere:
n = sqrt( x.^2+y.^2+z.^2 );
x = x./n;
y = y./n;
z = z./n;

[m,n] = size(I);
x = reshape( x,m,n);
y = reshape( y,m,n);
z = reshape( z,m,n);

warp(x,y,z, uint8(I));
%warp(-x,-y,-z, uint8(I));
axis equal
grid on
box on


%% confidence regions on sphere: point cloud of samples
N = 250;
% X = mvnrnd(v, qu*eCov, N)';
X = myrandn(v, qu*eCov, N);
for k=1:3
    idx = 3*(k-1)+(1:3);
    x = iK*X(idx,:);
    
    % plot vanishing points
    vn = iK*v(idx);
    vn = vn/norm(vn);
    plot3( +vn(1), +vn(2), +vn(3), ['.' color(k)], 'MarkerSize', 10)
    plot3( -vn(1), -vn(2), -vn(3), ['.' color(k)], 'MarkerSize', 10)
    
    % plot samples for confidence region
    for i=1:N
        y = x(:,i)/norm(x(:,i));
        plot3( +y(1), +y(2), +y(3), ['.' color(k)]);
        plot3( -y(1), -y(2), -y(3), ['.' color(k)]);
    end
end

return