function h = plot_conic_explicit( C, varargin )

% explicit plot of conic (ellipse or hyperbola)
%
% h = plot_conic_explicit( C, ... ) plots the conic defined by the 3x3 matrix
% C explicitly. Additional parameter/value pairs ar passed to Matlab's plot
% function.
%
% $Log: plot_conic_explicit.m,v $
% Revision 1.1  2009/08/03 11:10:33  Meidow
% *** empty log message ***
%

C = C/norm(C);

N = 100;  % number of supporting points
a = 2.0;  % length of hyperbola


Chh = C(1:2,1:2);
ch0 = C(1:2,  3);
c00 = C(  3,  3);

d = det( Chh );
x0 = -inv(Chh) *ch0;             % centre point
h = plot( x0(1), x0(2), 'k.');
set(h, varargin{:} );

c00q = c00 -ch0'*inv(Chh)*ch0;
[Rho,Lambda] = eig( -Chh/ c00q );

lambda = diag(Lambda);

hold on
switch sign(d)
    case +1
        
        %  (1) plot ellipse
        if lambda(1)<0
            lambda = -lambda;
        end
       
        t = linspace(0,2*pi, N);
        x = sqrt(1/lambda(1)) * sin(t);
        y = sqrt(1/lambda(2)) * cos(t);
        x = repmat(x0,1,N) + Rho*[x; y];
        h = [h; plot( x(1,:), x(2,:), 'k-')];
        set( h, varargin{:}  );
        
    case -1
        % (2) plot hyperbola
        if lambda(2)<0
            lambda = flipud(lambda);
            Rho = fliplr(Rho);
        end
    
        t = linspace(-asinh(a), +asinh(a), N);
        % t = linspace(-pi,pi, N);

        x = sqrt(1/-lambda(1)) *sinh(t);
        y = sqrt(1/+lambda(2))* cosh(t);
        x1 = repmat(x0, 1, N) + Rho*[x; +y];
        x2 = repmat(x0, 1, N) + Rho*[x; -y];
        h = plot( x1(1,:), x1(2,:), 'k-');
        set( h, varargin{:} );

        h = [h; plot( x2(1,:), x2(2,:), 'k-')];
        set( h, varargin{:} );

    otherwise
        error('degenrated conic')
end

return